@@ -125,7 +125,7 @@ def rmvirtualenvs(envs):
 			env = os.path.join(workon_home, env)
 			if os.environ.get('VIRTUAL_ENV') == env:
 				print("ERROR: You cannot remove the active environment \
-	(%s)." % env, file=sys.stderr)
+(%s)." % env, file=sys.stderr)
 				break
 			try:
 				shutil.rmtree(env)
@@ -156,8 +156,8 @@ def showvirtualenv_cmd():
 
 
 def lsvirtualenv(verbose):
-	envs = [env.split(os.path.sep)[-3] for env in
-			glob(os.path.join(workon_home, '*', env_bin_dir, 'python'))]
+	envs = set(env.split(os.path.sep)[-3] for env in
+			glob(os.path.join(workon_home, '*', env_bin_dir, 'python*')))
 	for env in envs:
 		deploy_inve(get_inve(env))
 
